@@ -18,16 +18,16 @@ print('''static const GeglModuleInfo modinfo = {
 GEGL_MODULE_ABI_VERSION
 };
 
-const GeglModuleInfo * gegl_module_query (GTypeModule *module);
-gboolean gegl_module_register (GTypeModule *module);
+G_MODULE_EXPORT const GeglModuleInfo * gegl_module_query (GTypeModule *module);
+G_MODULE_EXPORT gboolean gegl_module_register (GTypeModule *module);
 
-G_MODULE_EXPORT const GeglModuleInfo *
+const GeglModuleInfo *
 gegl_module_query (GTypeModule *module)
 {
   return &modinfo;
 }
 
-G_MODULE_EXPORT gboolean
+gboolean
 gegl_module_register (GTypeModule *module)
 {''')
 
